@@ -19,6 +19,7 @@
 // Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2018 Adam Reichold <adam.reichold@t-online.de>
 // Copyright (C) 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
+// Copyright (C) 2020 Albert Astals Cid <aacid@kde.org>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -35,7 +36,7 @@
 
 /* Defines the poppler version. */
 #ifndef POPPLER_VERSION
-#define POPPLER_VERSION "20.10.0"
+#define POPPLER_VERSION "20.12.1"
 #endif
 
 /* Use single precision arithmetic in the Splash backend */
@@ -116,6 +117,11 @@
 #define USE_BOOST_HEADERS 1
 #endif
 
+/* Is splash backend available */
+#ifndef HAVE_SPLASH
+#define HAVE_SPLASH 1
+#endif
+
 //------------------------------------------------------------------------
 // version
 //------------------------------------------------------------------------
